package org.colinvella.fancyfish.block;

import org.colinvella.fancyfish.achievement.ModAchievements;
import org.colinvella.fancyfish.creativetab.ModCreativeTabs;

import net.minecraft.block.material.Material;
import net.minecraft.block.properties.IProperty;
import net.minecraft.block.properties.PropertyBool;
import net.minecraft.block.state.BlockState;
import net.minecraft.block.state.IBlockState;
import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.entity.EntityLivingBase;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.ItemStack;
import net.minecraft.util.BlockPos;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.EnumWorldBlockLayer;
import net.minecraft.world.IBlockAccess;
import net.minecraft.world.World;

public class LampShadeBlock extends ModBlock
{
	public static final String ID = "LampShade";
	
	// properties mapped to meta data
	public static final PropertyBool PROPERTY_ON = PropertyBool.create("on");
	  
	public LampShadeBlock()
	{
		super(ID, Material.sand, ModCreativeTabs.FancyFishTab);
		this.setLightOpacity(0); // light passes through
	}
	
	// grant achievement when lamp shade placed (don't know how to detect on crafting)
	@Override
    public void onBlockPlacedBy(World worldIn, BlockPos pos, IBlockState state, EntityLivingBase placer, ItemStack stack)
	{
		if (placer instanceof EntityPlayer)
		{
			EntityPlayer entityPlayer = (EntityPlayer)placer;
			entityPlayer.addStat(ModAchievements.BuildLampShade, 1);
		}
		super.onBlockPlacedBy(worldIn, pos, state, placer, stack);
	};
	
	// override: return false as it is an irregular block
	@Override
	public boolean isOpaqueCube()
	{
		return false;
	}
	
	// override: treat block as translucent due to light shade
	@Override
	public EnumWorldBlockLayer getBlockLayer()
	{
		return EnumWorldBlockLayer.TRANSLUCENT;
	}
	
	// getStateFromMeta, getMetaFromState are used to inter-convert between the block's property values and
	//   the stored metadata (which must be an integer in the range 0 - 15 inclusive)
	@Override
	public IBlockState getStateFromMeta(int meta)
	{
		boolean on = meta > 0;
		return this.getDefaultState().withProperty(PROPERTY_ON, on);
	}
	
	@Override
	public int getMetaFromState(IBlockState state)
	{
		boolean filled = (Boolean)state.getValue(PROPERTY_ON);	
		return filled ? 1 : 0;
	}
	
	// necessary to define which properties your blocks use
	// will also affect the variants listed in the blocskstates model file
	@Override
	protected BlockState createBlockState()
	{
	    return new BlockState(this, new IProperty[] {PROPERTY_ON});
	}

	@Override
	public boolean onBlockActivated(World world, BlockPos pos, IBlockState state,
			EntityPlayer player, EnumFacing side, float hitX, float hitY, float hitZ)
	{
		IBlockState stateOn = state.withProperty(LampShadeBlock.PROPERTY_ON, true);
		IBlockState stateOff = state.withProperty(LampShadeBlock.PROPERTY_ON, false);
		
		if (state == stateOff)
		{
			world.setBlockState(pos, stateOn);
		}
		else
		{
			world.setBlockState(pos, stateOff);			
		}
		
        world.playSoundEffect((double)pos.getX() + 0.5D, (double)pos.getY() + 0.5D, (double)pos.getZ() + 0.5D, "random.click", 0.3F, 0.6F);
					
	    return true;
	}
	
	// returns light value depending on blockstate
	@Override
	public int getLightValue(IBlockAccess world, BlockPos pos)
	{
		IBlockState state = world.getBlockState(pos);
		IBlockState stateOn = state.withProperty(LampShadeBlock.PROPERTY_ON, true);

		return state == stateOn ? 15 : 0;
	}
}
