package org.colinvella.fancyfish.event;

import org.colinvella.fancyfish.block.FishTankBlock;
import org.colinvella.fancyfish.block.ModBlockRegistry;

import net.minecraft.block.Block;
import net.minecraft.block.state.IBlockState;
import net.minecraft.init.Items;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.BlockPos;
import net.minecraft.util.ChatComponentTranslation;
import net.minecraft.world.World;
import net.minecraftforge.event.entity.player.FillBucketEvent;
import net.minecraftforge.fml.common.eventhandler.SubscribeEvent;

public class FishTankEventHandler extends ModEventHandler
{
	public static final String ID = "FishTank";
	
	public FishTankEventHandler()
	{
		super(ID);
	}
		
	@SubscribeEvent
	public void fillOrDrainTank(FillBucketEvent event)
	{			
		// determine target block position and current block state
		World world = event.world;		
		BlockPos blockPos = event.target.getBlockPos();
		IBlockState blockStateCurrent = world.getBlockState(blockPos);

		// determine current block (type)
		Block block = blockStateCurrent.getBlock();

		// do nothing else unless it's a fish tank
		if (block != ModBlockRegistry.FishTank)
			return;

		// prevent further processing (e.g. to prevent water flooding!)
		event.setCanceled(true);

		// get equipped item
		Item equippedItem = event.current.getItem();
		logger.info("equipped item = " + equippedItem);
		
		// do nothing else unless the equipped item is an empty bucket or a water-filled one
		if (equippedItem != Items.water_bucket && equippedItem != Items.bucket)
			return;
		
		// determine empty and filled block states for fish thank (only once!)
		if (blockStateFilled == null)
		{
			blockStateFilled = blockStateCurrent.withProperty(FishTankBlock.PROPERTY_FILLED, true);
			blockStateEmpty = blockStateCurrent.withProperty(FishTankBlock.PROPERTY_FILLED, false);
		}
		
		if (equippedItem == Items.water_bucket)
		{
			if (blockStateCurrent == blockStateEmpty)
			{
				// drain water bucket if not in Creative
				if (!event.entityPlayer.capabilities.isCreativeMode)
					event.entityPlayer.setCurrentItemOrArmor(0, new ItemStack(Items.bucket));

				// change block state to filled
			    world.setBlockState(blockPos, blockStateFilled);	
			    
			    logger.debug("filled!");
			}
			else
			{
				if (!world.isRemote)
					event.entityPlayer.addChatMessage(new ChatComponentTranslation("tile.FishTank.message.alreadyFilled"));
			}
				
		} else if (equippedItem == Items.bucket)
		{
			if (blockStateCurrent == blockStateFilled)
			{
				// fill water bucket if not in Creative
				if (!event.entityPlayer.capabilities.isCreativeMode)
					event.entityPlayer.setCurrentItemOrArmor(0, new ItemStack(Items.water_bucket));

				// change block state to empty
			    world.setBlockState(blockPos, blockStateEmpty);	
			    
			    logger.info("emptied!");
			}
			else
			{
				if (!world.isRemote)
					event.entityPlayer.addChatMessage(new ChatComponentTranslation("tile.FishTank.message.alreadyEmpty"));
			}
		}
	}
	
	// private block state references
	private IBlockState blockStateFilled;
	private IBlockState blockStateEmpty;

}
