package org.colinvella.fancyfish.inventory;

import org.colinvella.fancyfish.item.CapturedFishItem;
import org.colinvella.fancyfish.item.LiveFishItem;
import org.colinvella.fancyfish.item.ModItemRegistry;

import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.IInventory;
import net.minecraft.inventory.Slot;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.ChatComponentTranslation;

public class FishSlot extends Slot
{

	public FishSlot(IInventory inventoryIn, int index, int xPosition, int yPosition)
	{
		super(inventoryIn, index, xPosition, yPosition);
	}
	
	@Override
	public boolean isItemValid(ItemStack itemStack)
	{
		// prevent swapping to avoid live fish items outside bowl
		if (this.getHasStack())
			return false;
		
		// only live fish or fish in bows allowed
		Item item = itemStack.getItem();
		return item instanceof CapturedFishItem
			|| item instanceof LiveFishItem;
	}

	@Override
	public int getSlotStackLimit()
	{
		return 1;
	}	
	
	@Override
	public void onPickupFromSlot(EntityPlayer playerIn, ItemStack itemStack)
	{
		// check for an empty fish bowl in the player's inventory
		boolean matchedBowl = false;
		int playerSlotCount = playerIn.inventory.getSizeInventory();
		for (int playerSlotIndex = 0; playerSlotIndex < playerSlotCount; playerSlotIndex++)
		{
			ItemStack playerItemStack = playerIn.inventory.getStackInSlot(playerSlotIndex);
			if (playerItemStack == null)
				continue;
			
			Item playerItem = playerItemStack.getItem();
			if (playerItem == ModItemRegistry.FishBowl)
			{
				// if an empty bowl is found, convert the live fish into a captured one
				LiveFishItem liveFishItem = (LiveFishItem)itemStack.getItem();
				itemStack.setItem(ModItemRegistry.getCapturedFromLive(liveFishItem));
				
				// and remove the empty bowl from the inventory
				playerIn.inventory.setInventorySlotContents(playerSlotIndex, null);
				
				// mark the inventory for client-server synch
				// and take note if bowl found
				playerIn.inventory.markDirty();
				matchedBowl = true;
				break;
			}
		}
		
		if (!matchedBowl)
		{
			// if there is no empty fish back, put the fish back and notify the player
			// of the need for a bowl
			this.putStack(itemStack);
			playerIn.inventory.setItemStack(null);
			
			if (!playerIn.worldObj.isRemote)
				playerIn.addChatMessage(new ChatComponentTranslation("tile.FishTank.message.needEmptyBowl"));
		}
		
		super.onPickupFromSlot(playerIn, itemStack);
	}
}
